@@ -759,3 +759,47 @@ fn test_use_crc32_convenience_method_returns_same_crc32_as_flate2() {
 
     assert_eq!(flate2_crc32, libdeflate_crc32);
 }
+
+// adler32
+#[test]
+fn test_use_adler32_reader_to_compute_adler32_of_fixture_returns_same_adler32_as_adler32_crate(
+) {
+    // This assumes that adler32 crate implementation returns a
+    // correct value, which is a pretty safe assumption.
+
+    let input_data = read_fixture_content();
+
+    let crate_adler32 = {
+        let mut adler32 = adler32::RollingAdler32::new();
+        adler32.update_buffer(&input_data);
+        adler32.update_buffer(&input_data);
+        adler32.hash()
+    };
+
+    let libdeflate_adler32 = {
+        let mut adler32 = libdeflater::Adler32::new();
+        adler32.update(&input_data);
+        adler32.update(&input_data);
+        adler32.sum()
+    };
+
+    assert_eq!(crate_adler32, libdeflate_adler32);
+}
+
+#[test]
+fn test_use_adler32_convenience_method_returns_same_adler32_as_adler32_crate() {
+    // This assumes that adler32 crate implementation returns a
+    // correct value, which is a pretty safe assumption.
+
+    let input_data = read_fixture_content();
+
+    let crate_adler32 = {
+        let mut adler32 = adler32::RollingAdler32::new();
+        adler32.update_buffer(&input_data);
+        adler32.hash()
+    };
+
+    let libdeflate_adler32 = libdeflater::adler32(&input_data);
+
+    assert_eq!(crate_adler32, libdeflate_adler32);
+}
\ No newline at end of file
